@@ -12,7 +12,7 @@
 #' P <- momentuHMM:::allProbs(m=example$m)
 #' }
 #' 
-#' @importFrom extraDistr dcat
+# #' @importFrom extraDistr dcat
 allProbs <- function(m)
 {
   
@@ -43,10 +43,10 @@ allProbs <- function(m)
     
     Par<-lapply(Par[distnames],function(x) c(t(x)))
     beta <- m$Par$beta$beta$est
-    pie <- m$Par$real$pi$est
+    pie <- m$Par$real[["pi"]]$est
     delta <- m$Par$real$delta$est
     if(!is.null(beta)) m$conditions$workBounds$beta<-matrix(c(-Inf,Inf),length(beta),2,byrow=TRUE)
-    if(!is.null(pie)) m$conditions$workBounds$pi <- matrix(c(-Inf,Inf),length(m$Par$beta$pi$est),2,byrow=TRUE)
+    if(!is.null(pie)) m$conditions$workBounds[["pi"]] <- matrix(c(-Inf,Inf),length(m$Par$beta[["pi"]]$est),2,byrow=TRUE)
     if(!is.null(m$Par$beta$delta$est)) m$conditions$workBounds$delta<-matrix(c(-Inf,Inf),length(m$Par$beta$delta$est),2,byrow=TRUE)
     
     g0 <- c(m$Par$beta$g0$est)
@@ -58,10 +58,10 @@ allProbs <- function(m)
     p <- inputs$p
     DMinputs<-getDM(data,inputs$DM,inputs$dist,nbStates,p$parNames,p$bounds,Par,m$conditions$zeroInflation,m$conditions$oneInflation,m$conditions$circularAngleMean)
     m$conditions$fullDM <- DMinputs$fullDM
-    m$mod$estimate <- n2w(Par,p$bounds,list(beta=beta,pi=m$Par$beta$pi$est,g0=g0,theta=theta),m$Par$beta$delta$est,nbStates,inputs$estAngleMean,inputs$DM,p$Bndind,inputs$dist)
+    m$mod$estimate <- n2w(Par,p$bounds,list(beta=beta,pi=m$Par$beta[["pi"]]$est,g0=g0,theta=theta),m$Par$beta$delta$est,nbStates,inputs$estAngleMean,inputs$DM,p$Bndind,inputs$dist)
   } else {
     beta <- m$mle$beta
-    pie <- m$mle$pi
+    pie <- m$mle[["pi"]]
     delta <- m$mle$delta
     g0 <- m$mle$g0
     theta <- m$mle$theta
@@ -86,7 +86,14 @@ allProbs <- function(m)
   par <- w2n(m$mod$estimate,m$conditions$bounds,lapply(m$conditions$fullDM,function(x) nrow(x)/nbStates),nbStates,nbCovs,m$conditions$estAngleMean,m$conditions$circularAngleMean,consensus,m$conditions$stationary,m$conditions$fullDM,m$conditions$DMind,nbObs,dist,m$conditions$Bndind,nc,meanind,m$covsDelta,m$conditions$workBounds,m$covsPi)
   
   Fun <- lapply(dist,function(x) paste("d",x,sep=""))
-  
+  for(i in names(Fun)){
+    if(Fun[[i]]=="dcat"){
+      if (!requireNamespace("extraDistr", quietly = TRUE))
+        stop("Package \"extraDistr\" needed for categorical distribution. Please install it.",
+             call. = FALSE)
+      dcat <- extraDistr::dcat
+    }
+  }
 
   probs <- matrix(1,nrow=nbObs,ncol=nbStates)
   
