@@ -1,8 +1,7 @@
 
-#' Plot \code{momentuHMMData}
-#' @method plot momentuHMMData
+#' Plot \code{momentuHMMData} or \code{momentuHierHMMData}
 #'
-#' @param x An object \code{momentuHMMData}
+#' @param x An object \code{momentuHMMData} or \code{momentuHierHMMData}
 #' @param dataNames Names of the variables to plot. Default is \code{dataNames=c("step","angle")}.
 #' @param animals Vector of indices or IDs of animals for which information will be plotted.
 #' Default: \code{NULL} ; all animals are plotted.
@@ -19,9 +18,10 @@
 #' plot(data,dataNames=c("step","angle","cov1","cov2"),
 #'      compact=TRUE,breaks=20,ask=FALSE)
 #'
+#' @aliases plot.momentuHierHMMData
 #' @export
 #' @importFrom graphics abline axis hist mtext par plot points
-
+#' @method plot momentuHMMData
 plot.momentuHMMData <- function(x,dataNames=c("step","angle"),animals=NULL,compact=FALSE,ask=TRUE,breaks="Sturges",...)
 {
   data <- x
@@ -66,7 +66,10 @@ plot.momentuHMMData <- function(x,dataNames=c("step","angle"),animals=NULL,compa
     dataNames <- dataNames[which(dataNames %in% names(data))]
   } else stop('dataNames not found in data')
   
-  if(all(c("step","angle") %in% dataNames)){
+  coordNames <- c("x","y")
+  if(!is.null(attr(data,'coords'))) coordNames <- attr(data,'coords')
+  
+  if(all(c("step","angle") %in% dataNames) | !is.null(attr(data,'coords'))){
     if(compact) {
       ################################
       ## Map of all animals' tracks ##
@@ -75,10 +78,10 @@ plot.momentuHMMData <- function(x,dataNames=c("step","angle"),animals=NULL,compa
 
       # determine bounds
       ind <- which(data$ID %in% unique(data$ID)[animalsInd])
-      xmin <- min(data$x[ind],na.rm=T)
-      xmax <- max(data$x[ind],na.rm=T)
-      ymin <- min(data$y[ind],na.rm=T)
-      ymax <- max(data$y[ind],na.rm=T)
+      xmin <- min(data[[coordNames[1]]][ind],na.rm=T)
+      xmax <- max(data[[coordNames[1]]][ind],na.rm=T)
+      ymin <- min(data[[coordNames[2]]][ind],na.rm=T)
+      ymax <- max(data[[coordNames[2]]][ind],na.rm=T)
       # make sure that x and y have same scale
       if(xmax-xmin>ymax-ymin) {
         ymid <- (ymax+ymin)/2
@@ -98,25 +101,25 @@ plot.momentuHMMData <- function(x,dataNames=c("step","angle"),animals=NULL,compa
         colors <- c("#E69F00", "#56B4E9", "#009E73", "#F0E442", "#0072B2", "#D55E00", "#CC79A7")
 
       ID <- unique(data$ID)[animalsInd[1]]
-      x <- data$x[which(data$ID==ID)]
-      y <- data$y[which(data$ID==ID)]
+      x <- data[[coordNames[1]]][which(data$ID==ID)]
+      y <- data[[coordNames[2]]][which(data$ID==ID)]
       # plot the first animal's track
       plot(x,y,type="o",pch=20,lwd=1.3,col=colors[1], cex=0.5,
-           xlim=c(xmin,xmax),ylim=c(ymin,ymax),xlab="x",ylab="y")
+           xlim=c(xmin,xmax),ylim=c(ymin,ymax),xlab=coordNames[1],ylab=coordNames[2])
 
       # add each other animal's track to the map
       for(zoo in animalsInd[-1]) {
         ID <- unique(data$ID)[zoo]
-        x <- data$x[which(data$ID==ID)]
-        y <- data$y[which(data$ID==ID)]
+        x <- data[[coordNames[1]]][which(data$ID==ID)]
+        y <- data[[coordNames[2]]][which(data$ID==ID)]
         points(x,y,type="o",pch=20,lwd=1.3,col=colors[zoo],cex=0.5)
       }
     }
   
     for(zoo in animalsInd) {
       ID <- unique(data$ID)[zoo]
-      x <- data$x[which(data$ID==ID)]
-      y <- data$y[which(data$ID==ID)]
+      x <- data[[coordNames[1]]][which(data$ID==ID)]
+      y <- data[[coordNames[2]]][which(data$ID==ID)]
       step <- data$step[which(data$ID==ID)]
       angle <- data$angle[which(data$ID==ID)]
 
@@ -126,48 +129,50 @@ plot.momentuHMMData <- function(x,dataNames=c("step","angle"),animals=NULL,compa
         ################################
         par(mfrow=c(1,1))
         # map of the animal's track
-        plot(x,y,type="o",lwd=1.3,xlab="x",ylab="y",pch=20,asp=1)
+        plot(x,y,type="o",lwd=1.3,xlab=coordNames[1],ylab=coordNames[2],pch=20,asp=1)
         mtext(paste("ID",ID),side=3,outer=TRUE,padj=2)
       }
 
       ##################################
       ## Steps and angles time series ##
       ##################################
-      par(mfrow=c(2,2))
-      plot(step,type="l",xlab="t",ylab="step length",
-           ylim=c(0,max(step,na.rm=T)))
-      plot(angle,type="l",xlab="t",ylab="turning angle (radians)",
-           ylim=c(-pi,pi),yaxt="n")
-      axis(2, at = c(-pi, -pi/2, 0, pi/2, pi),
-           labels = expression(-pi, -pi/2, 0, pi/2, pi))
-      abline(h=c(-pi,0,pi),lty=2)
-
-      #################################
-      ## Steps and angles histograms ##
-      #################################
-      hist(step,xlab="step length",main="", col="grey",border="white",breaks=breaks)
-
-      h <- hist(angle,breaks=breaks,plot=FALSE) # to define the breaks
-
-      hist(angle,xlab="turning angle (radians)",main="", col="grey",border="white",
-           breaks=seq(-pi,pi,length=length(h$breaks)),xaxt="n")
-      axis(1, at = c(-pi, -pi/2, 0, pi/2, pi),
-           labels = expression(-pi, -pi/2, 0, pi/2, pi))
-
-      mtext(paste("ID",ID),side=3,outer=TRUE,padj=2)
+      if(all(c("step","angle") %in% dataNames)){
+        par(mfrow=c(2,2))
+        plot(step,type="l",xlab="t",ylab="step length",
+             ylim=c(0,max(step,na.rm=T)))
+        plot(angle,type="l",xlab="t",ylab="turning angle (radians)",
+             ylim=c(-pi,pi),yaxt="n")
+        axis(2, at = c(-pi, -pi/2, 0, pi/2, pi),
+             labels = expression(-pi, -pi/2, 0, pi/2, pi))
+        abline(h=c(-pi,0,pi),lty=2)
+  
+        #################################
+        ## Steps and angles histograms ##
+        #################################
+        hist(step,xlab="step length",main="", col="grey",border="white",breaks=breaks)
+  
+        h <- hist(angle,breaks=breaks,plot=FALSE) # to define the breaks
+  
+        hist(angle,xlab="turning angle (radians)",main="", col="grey",border="white",
+             breaks=seq(-pi,pi,length=length(h$breaks)),xaxt="n")
+        axis(1, at = c(-pi, -pi/2, 0, pi/2, pi),
+             labels = expression(-pi, -pi/2, 0, pi/2, pi))
+  
+        mtext(paste("ID",ID),side=3,outer=TRUE,padj=2)
+      }
     }
-    dataNames<-dataNames[-which(dataNames %in% c("step","angle"))]
+    if(all(c("step","angle") %in% dataNames)) dataNames<-dataNames[-which(dataNames %in% c("step","angle"))]
     
-  } else if(!is.null(data$step) & (is.null(data$angle) | !is.null(data$y))) { # only step length is provided
-    if(all(data$y==0)){
+  } else if(!is.null(data$step) & !is.null(data[[coordNames[1]]]) & (is.null(data$angle) | !is.null(data[[coordNames[2]]]))) { # only step length is provided
+    if(all(data[[coordNames[2]]]==0)){
       for(zoo in animalsInd) {
           ################
           ## Plot track ##
           ################*
           par(mfrow=c(1,1))
           ID <- unique(data$ID)[zoo]
-          x <- data$x[which(data$ID==ID)]
-          plot(x, type="o",lwd=1.3, xlab="time", ylab="x", pch=20)
+          x <- data[[coordNames[1]]][which(data$ID==ID)]
+          plot(x, type="o",lwd=1.3, xlab="time", ylab=coordNames[1], pch=20)
           mtext(paste("ID",ID),side=3,outer=TRUE,padj=2)
           
           ##########################################
@@ -196,7 +201,7 @@ plot.momentuHMMData <- function(x,dataNames=c("step","angle"),animals=NULL,compa
       ID <- unique(data$ID)[zoo]
       genData <- data[[i]][which(data$ID==ID)]
       # step length time series
-      plot(genData,type="l",xlab="t",ylab=i,
+      plot(which(!is.na(genData)),genData[which(!is.na(genData))],type="l",xlab="t",ylab=i,
            ylim=range(genData,na.rm=TRUE))
       # step length histogram
       hist(genData,xlab=i,main="",col="grey",border="white",breaks=breaks)
@@ -209,3 +214,10 @@ plot.momentuHMMData <- function(x,dataNames=c("step","angle"),animals=NULL,compa
   par(mfrow=c(1,1))
   par(mar=c(5,4,4,2))
 }
+
+#' @method plot momentuHierHMMData
+#' @export
+plot.momentuHierHMMData <- function(x,dataNames=c("step","angle"),animals=NULL,compact=FALSE,ask=TRUE,breaks="Sturges",...)
+{
+  plot(momentuHMMData(x),dataNames=dataNames,animals=animals,compact=compact,ask=ask,breaks=breaks,...)
+}
\ No newline at end of file
